==> cscec5b-sync-api-3.0.1-20230314.072830-31-sources.jar: com/ejianc/business/sync/vo/CalculateDetailVO.java <==
package com.ejianc.business.sync.vo;

import java.math.BigDecimal;

public class CalculateDetailVO {
    private String pkId;//轻量化主表主键 VARCHAR2(100)
    private String pkSettleId;//轻量化子表主键 VARCHAR2(100)
    private String htflh;//合同分录号 VARCHAR2(30)
    private BigDecimal nstopnum;//停租数量 NUMBER(20,8)
    private BigDecimal nhireworknum;//租金工作量 NUMBER(20,8)
    private BigDecimal nhiredays;//租金天数 NUMBER(20,8)
    private String dbegindate;//起始日期 CHAR(10)
    private String denddate;//终止日期 CHAR(10)
    private String pkInvcl;//物资大类PK CHAR(20)
    private BigDecimal nsettlenum;//结算数量 NUMBER(20,8)
    private BigDecimal ninnum;//进场数量 NUMBER(20,8)
    private BigDecimal noriginhireprice;//租金单价 NUMBER(20,8)
    private BigDecimal noriginhiremny;//租金 NUMBER(20,8)
    private BigDecimal nwastenum;//报废数量 NUMBER(20,8)
    private BigDecimal noutnum;//退场数量 NUMBER(20,8)
    private String pkContract;//合同 CHAR(20)
    private String pkContractB;//合同清单ID CHAR(20)
    private String pkInvbasdoc;//存货基础ID CHAR(20)
    private String pkInvmandoc;//存货管理ID CHAR(20)
    private String pkMeasdoc;//单位ID CHAR(20)
    private String pkMeasdoc1;//辅单位ID CHAR(20)
    private Integer nflag;//NC是否加截 interger 默认为0
    private String ts;

    public String getPkId() {
        return pkId;
    }

    public void setPkId(String pkId) {
        this.pkId = pkId;
    }

    public String getPkSettleId() {
        return pkSettleId;
    }

    public void setPkSettleId(String pkSettleId) {
        this.pkSettleId = pkSettleId;
    }

    public String getHtflh() {
        return htflh;
    }

    public void setHtflh(String htflh) {
        this.htflh = htflh;
    }

    public BigDecimal getNstopnum() {
        return nstopnum;
    }

    public void setNstopnum(BigDecimal nstopnum) {
        this.nstopnum = nstopnum;
    }

    public BigDecimal getNhireworknum() {
        return nhireworknum;
    }

    public void setNhireworknum(BigDecimal nhireworknum) {
        this.nhireworknum = nhireworknum;
    }

    public BigDecimal getNhiredays() {
        return nhiredays;
    }

    public void setNhiredays(BigDecimal nhiredays) {
        this.nhiredays = nhiredays;
    }

    public String getDbegindate() {
        return dbegindate;
    }

    public void setDbegindate(String dbegindate) {
        this.dbegindate = dbegindate;
    }

    public String getDenddate() {
        return denddate;
    }

    public void setDenddate(String denddate) {
        this.denddate = denddate;
    }

    public String getPkInvcl() {
        return pkInvcl;
    }

    public void setPkInvcl(String pkInvcl) {
        this.pkInvcl = pkInvcl;
    }

    public BigDecimal getNsettlenum() {
        return nsettlenum;
    }

    public void setNsettlenum(BigDecimal nsettlenum) {
        this.nsettlenum = nsettlenum;
    }

    public BigDecimal getNinnum() {
        return ninnum;
    }

    public void setNinnum(BigDecimal ninnum) {
        this.ninnum = ninnum;
    }

    public BigDecimal getNoriginhireprice() {
        return noriginhireprice;
    }

    public void setNoriginhireprice(BigDecimal noriginhireprice) {
        this.noriginhireprice = noriginhireprice;
    }

    public BigDecimal getNoriginhiremny() {
        return noriginhiremny;
    }

    public void setNoriginhiremny(BigDecimal noriginhiremny) {
        this.noriginhiremny = noriginhiremny;
    }

    public BigDecimal getNwastenum() {
        return nwastenum;
    }

    public void setNwastenum(BigDecimal nwastenum) {
        this.nwastenum = nwastenum;
    }

    public BigDecimal getNoutnum() {
        return noutnum;
    }

    public void setNoutnum(BigDecimal noutnum) {
        this.noutnum = noutnum;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getPkContractB() {
        return pkContractB;
    }

    public void setPkContractB(String pkContractB) {
        this.pkContractB = pkContractB;
    }

    public String getPkInvbasdoc() {
        return pkInvbasdoc;
    }

    public void setPkInvbasdoc(String pkInvbasdoc) {
        this.pkInvbasdoc = pkInvbasdoc;
    }

    public String getPkInvmandoc() {
        return pkInvmandoc;
    }

    public void setPkInvmandoc(String pkInvmandoc) {
        this.pkInvmandoc = pkInvmandoc;
    }

    public String getPkMeasdoc() {
        return pkMeasdoc;
    }

    public void setPkMeasdoc(String pkMeasdoc) {
        this.pkMeasdoc = pkMeasdoc;
    }

    public String getPkMeasdoc1() {
        return pkMeasdoc1;
    }

    public void setPkMeasdoc1(String pkMeasdoc1) {
        this.pkMeasdoc1 = pkMeasdoc1;
    }

    public Integer getNflag() {
        return nflag;
    }

    public void setNflag(Integer nflag) {
        this.nflag = nflag;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }
}

==> cscec5b-sync-api-3.0.1-20231120.091858-56-sources.jar: com/ejianc/business/sync/vo/CalculateDetailVO.java <==
package com.ejianc.business.sync.vo;

import java.math.BigDecimal;

public class CalculateDetailVO {
    private String pkId;//轻量化主表主键 VARCHAR2(100)
    private String pkSettleId;//轻量化子表主键 VARCHAR2(100)
    private String htflh;//合同分录号 VARCHAR2(30)
    private BigDecimal nstopnum;//停租数量 NUMBER(20,8)
    private BigDecimal nhireworknum;//租金工作量 NUMBER(20,8)
    private BigDecimal nhiredays;//租金天数 NUMBER(20,8)
    private String dbegindate;//起始日期 CHAR(10)
    private String denddate;//终止日期 CHAR(10)
    private String pkInvcl;//物资大类PK CHAR(20)
    private BigDecimal nsettlenum;//结算数量 NUMBER(20,8)
    private BigDecimal ninnum;//进场数量 NUMBER(20,8)
    private BigDecimal noriginhireprice;//租金单价 NUMBER(20,8)
    private BigDecimal noriginhiremny;//租金 NUMBER(20,8)
    private BigDecimal nwastenum;//报废数量 NUMBER(20,8)
    private BigDecimal noutnum;//退场数量 NUMBER(20,8)
    private String pkContract;//合同 CHAR(20)
    private String pkContractB;//合同清单ID CHAR(20)
    private String pkInvbasdoc;//存货基础ID CHAR(20)
    private String pkInvmandoc;//存货管理ID CHAR(20)
    private String pkMeasdoc;//单位ID CHAR(20)
    private String pkMeasdoc1;//辅单位ID CHAR(20)
    private Integer nflag;//NC是否加截 interger 默认为0
    private Integer sequence;//序号
    private String ts;

    public String getPkId() {
        return pkId;
    }

    public void setPkId(String pkId) {
        this.pkId = pkId;
    }

    public String getPkSettleId() {
        return pkSettleId;
    }

    public void setPkSettleId(String pkSettleId) {
        this.pkSettleId = pkSettleId;
    }

    public String getHtflh() {
        return htflh;
    }

    public void setHtflh(String htflh) {
        this.htflh = htflh;
    }

    public BigDecimal getNstopnum() {
        return nstopnum;
    }

    public void setNstopnum(BigDecimal nstopnum) {
        this.nstopnum = nstopnum;
    }

    public BigDecimal getNhireworknum() {
        return nhireworknum;
    }

    public void setNhireworknum(BigDecimal nhireworknum) {
        this.nhireworknum = nhireworknum;
    }

    public BigDecimal getNhiredays() {
        return nhiredays;
    }

    public void setNhiredays(BigDecimal nhiredays) {
        this.nhiredays = nhiredays;
    }

    public String getDbegindate() {
        return dbegindate;
    }

    public void setDbegindate(String dbegindate) {
        this.dbegindate = dbegindate;
    }

    public String getDenddate() {
        return denddate;
    }

    public void setDenddate(String denddate) {
        this.denddate = denddate;
    }

    public String getPkInvcl() {
        return pkInvcl;
    }

    public void setPkInvcl(String pkInvcl) {
        this.pkInvcl = pkInvcl;
    }

    public BigDecimal getNsettlenum() {
        return nsettlenum;
    }

    public void setNsettlenum(BigDecimal nsettlenum) {
        this.nsettlenum = nsettlenum;
    }

    public BigDecimal getNinnum() {
        return ninnum;
    }

    public void setNinnum(BigDecimal ninnum) {
        this.ninnum = ninnum;
    }

    public BigDecimal getNoriginhireprice() {
        return noriginhireprice;
    }

    public void setNoriginhireprice(BigDecimal noriginhireprice) {
        this.noriginhireprice = noriginhireprice;
    }

    public BigDecimal getNoriginhiremny() {
        return noriginhiremny;
    }

    public void setNoriginhiremny(BigDecimal noriginhiremny) {
        this.noriginhiremny = noriginhiremny;
    }

    public BigDecimal getNwastenum() {
        return nwastenum;
    }

    public void setNwastenum(BigDecimal nwastenum) {
        this.nwastenum = nwastenum;
    }

    public BigDecimal getNoutnum() {
        return noutnum;
    }

    public void setNoutnum(BigDecimal noutnum) {
        this.noutnum = noutnum;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getPkContractB() {
        return pkContractB;
    }

    public void setPkContractB(String pkContractB) {
        this.pkContractB = pkContractB;
    }

    public String getPkInvbasdoc() {
        return pkInvbasdoc;
    }

    public void setPkInvbasdoc(String pkInvbasdoc) {
        this.pkInvbasdoc = pkInvbasdoc;
    }

    public String getPkInvmandoc() {
        return pkInvmandoc;
    }

    public void setPkInvmandoc(String pkInvmandoc) {
        this.pkInvmandoc = pkInvmandoc;
    }

    public String getPkMeasdoc() {
        return pkMeasdoc;
    }

    public void setPkMeasdoc(String pkMeasdoc) {
        this.pkMeasdoc = pkMeasdoc;
    }

    public String getPkMeasdoc1() {
        return pkMeasdoc1;
    }

    public void setPkMeasdoc1(String pkMeasdoc1) {
        this.pkMeasdoc1 = pkMeasdoc1;
    }

    public Integer getNflag() {
        return nflag;
    }

    public void setNflag(Integer nflag) {
        this.nflag = nflag;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
}
